@@ -9,7 +9,8 @@ use metaclass 'Moose::Meta::Class';
 
 use Carp 'confess';
 
-our $VERSION = '0.06';
+our $VERSION   = '0.08';
+our $AUTHORITY = 'cpan:STEVAN';
 
 sub new {
     my $class = shift;
@@ -28,6 +29,10 @@ sub new {
 }
 
 sub BUILDALL {
+    # NOTE: we ask Perl if we even 
+    # need to do this first, to avoid
+    # extra meta level calls
+	return unless $_[0]->can('BUILD');    
 	my ($self, $params) = @_;
 	foreach my $method (reverse $self->meta->find_all_methods_by_name('BUILD')) {
 		$method->{code}->($self, $params);
@@ -35,7 +40,11 @@ sub BUILDALL {
 }
 
 sub DEMOLISHALL {
-	my $self = shift;
+    # NOTE: we ask Perl if we even 
+    # need to do this first, to avoid
+    # extra meta level calls    
+	return unless $_[0]->can('DEMOLISH');    
+	my $self = shift;	
 	foreach my $method ($self->meta->find_all_methods_by_name('DEMOLISH')) {
 		$method->{code}->($self);
 	}	
@@ -143,7 +152,7 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006 by Infinity Interactive, Inc.
+Copyright 2006, 2007 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
